pub struct CowVariant {
pub key: Identifier,
pub asset_id: Identifier,
pub baby_asset_id: Identifier,
pub model: CowModelType,
pub spawn_conditions: &'static [SpawnConditionEntry],
}Expand description
Represents a full cow variant definition from a data pack JSON file.
Fields
key: Identifierasset_id: Identifierbaby_asset_id: Identifiermodel: CowModelTypespawn_conditions: &'static [SpawnConditionEntry]Trait Implementations
Sourceimpl Debug for CowVariant
impl Debug for CowVariant
impl Eq for CowVariant
Sourceimpl PartialEq for CowVariant
impl PartialEq for CowVariant
Sourceimpl RegistryEntry for CowVariant
impl RegistryEntry for CowVariant
Sourceimpl RegistryReferenceEntry for CowVariant
impl RegistryReferenceEntry for CowVariant
Sourceconst REGISTRY_NAME: &'static str = "cow variant"
const REGISTRY_NAME: &'static str = "cow variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &CowVariant
impl ToNbtTag for &CowVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>